@@ -6,10 +6,12 @@
 #'   assignments (factor \code{cluster}), and arm assignments (factor \code{arm}). Optionally specification of a buffer zone (logical \code{buffer});
 #'   any other variables required for subsequent analysis.
 #' @param design list: an optional list containing the requirements for the power of the trial
-#' @param geoscale standard deviation of random displacement from each settlement cluster center (for new objects)
-#' @param locations number of locations in population (for new objects)
-#' @param kappa intensity of Poisson process of settlement cluster centers (for new objects)
-#' @param mu mean  number of points per settlement cluster (for new objects)
+#' @param geoscale numeric: standard deviation of random displacement from each settlement cluster center (for new objects)
+#' @param locations integer: number of locations in population (for new objects)
+#' @param kappa numeric: intensity of Poisson process of settlement cluster centers (for new objects)
+#' @param mu numeric: mean number of points per settlement cluster (for new objects)
+#' @param geometry  with valid values \code{'point'} (the default, corresponding to point locations), \code{'triangle'},
+#' \code{'square'} and \code{'hexagon'} corresponding to grids constructed from pixels of regular polygons.
 #' @export
 #' @returns A list of class \code{"CRTsp"} containing the following components:
 #'  \tabular{lll}{
@@ -33,22 +35,22 @@
 #' corresponding to a novel simulated human settlement pattern. This is generated using the
 #' Thomas algorithm (\code{rThomas}) in [\code{spatstat.random}](https://CRAN.R-project.org/package=spatstat.random)
 #' allowing the user to defined the density of locations and degree of spatial clustering.
-#' The resulting trial data frame comprises a set of Cartesian coordinates centred at the origin.
+#' The resulting trial data frame comprises a set of Cartesian coordinates centred at the origin.\cr\cr
 #' @export
 #' @examples
 #' {# Generate a simulated area with 10,000 locations
 #' example_area = CRTsp(geoscale = 1, locations=10000, kappa=3, mu=40)
 #' summary(example_area)
 #' }
-CRTsp <- function(x = NULL, design = NULL,
-                  geoscale = NULL, locations = NULL, kappa = NULL, mu = NULL) {
+CRTsp <- function(x = NULL, design = NULL, geoscale = NULL, locations = NULL,
+                  kappa = NULL, mu = NULL, geometry = 'point') {
   centroid <- list(lat = NULL, long = NULL)
   if(identical(class(x),"CRTsp")) {
     CRT <- x
     if(!is.null(design)) CRT$design <- design
     centroid <- if(!is.null(CRT$geom_full$centroid$lat)) CRT$geom_full$centroid
-  } else if(identical(class(x),"data.frame")) {
-    CRT <- list(trial = x, design = design)
+  } else if("data.frame" %in% class(x)) {
+    CRT <- list(trial = data.frame(x), design = design)
   } else if(is.null(x)) {
     if (!is.null(geoscale) & !is.null(locations)
         & !is.null(kappa) & !is.null(mu)){
@@ -59,20 +61,25 @@ CRTsp <- function(x = NULL, design = NULL,
       CRT <- list(trial = data.frame(x=numeric(0),y=numeric(0)), design = design)
     }
   }
-  if(is.null(CRT$design)) CRT$design <- list(locations = NULL,
+  if(is.null(CRT$design)) CRT$design <- list(locations = NULL, geometry = geometry,
                                              alpha = NULL, desiredPower = NULL, effect = NULL, yC = NULL,
                                              outcome_type = NULL, sigma2 = NULL, denominator = NULL, N = NULL,
-                                             ICC = NULL, k = NULL, d_h = NULL)
+                                             ICC = NULL, k = NULL, d_h = NULL, spillover_interval = NULL,
+                                             contaminate_pop_pr = 0, distance_distribution = NULL)
   if(is.null(CRT$trial)) CRT$trial <- data.frame(x=numeric(0),y=numeric(0))
   CRT$geom_full <- get_geom(trial = CRT$trial, design = CRT$design)
   CRT$geom_full$centroid <- centroid
+  empty_geom <- list(locations = 0, sd_h = NULL, k= NULL, uniquelocations = 0, mean_h = NULL,
+    DE = NULL, power = NULL, clustersRequired = NULL)
   if (is.null(CRT$trial$buffer)) {
-    CRT$geom_core <- list(
-      locations = 0,sd_h = NULL, k= NULL, records = 0, mean_h = NULL,
-      DE = NULL, power = NULL, clustersRequired = NULL)
+    CRT$geom_core <- empty_geom
   } else {
-    CRT$geom_core <- get_geom(trial = CRT$trial[CRT$trial$buffer == FALSE, ],
-                              design = CRT$design)
+    if (all(CRT$trial$buffer == TRUE)) {
+      CRT$geom_core <- empty_geom
+    } else {
+      CRT$geom_core <- get_geom(trial = CRT$trial[CRT$trial$buffer == FALSE, ],
+                                design = CRT$design)
+    }
   }
   return(validate_CRTsp(new_CRTsp(CRT)))
 }
@@ -99,8 +106,10 @@ validate_CRTsp <- function(x) {
     if (!identical(class(values$trial),"data.frame")){
       stop("The trial object in `x` must be a data frame")
     }
-    if (nrow(values$trial) != values$geom_full$records){
-      stop("The geom_full object in `x` is invalid")
+    if (nrow(values$trial) > 0) {
+      if (nrow(values$trial) != values$geom_full$locations){
+        stop("The geom_full object in `x` is invalid")
+      }
     }
   }
   return(x)
@@ -124,7 +133,9 @@ summary.CRTsp <- function(object, maskbuffer = 0.2, ...) {
   on.exit(options(digits = defaultdigits))
   options(digits = 3)
   cat("===============================CLUSTER RANDOMISED TRIAL ===========================\n")
-  output <- matrix("  ", nrow = 22, ncol = 2)
+  output <- matrix("  ", nrow = 23, ncol = 3)
+  required_cols <- c(1, 2, 3)
+  # The third column is to avoid loss of row names when the object is reduced to a vector
   rownames(output) <- paste0("row ", 1:nrow(output))
   rownames(output)[1] <- "Locations and Clusters\n----------------------                                "
   output[1, 1] <- "-"
@@ -139,7 +150,11 @@ summary.CRTsp <- function(object, maskbuffer = 0.2, ...) {
 
   if (identical(unname(output[2, 1]),"(x, y)")) {
     cat("\nSummary of coordinates\n----------------------\n")
-    coordinate.summary <- with(object$trial, summary(cbind(x, y)))
+    if(is.null(object$trial$nearestDiscord)) {
+      coordinate.summary <- with(object$trial, summary(cbind(x, y)))
+    } else {
+      coordinate.summary <- with(object$trial, summary(cbind(x, y, nearestDiscord)))
+    }
     rownames(coordinate.summary) <- substr(coordinate.summary[, 1], 1, 8)
     coordinate.summary[, ] <- substr(coordinate.summary[, ], 9, 13)
     print(t(coordinate.summary))
@@ -148,8 +163,10 @@ summary.CRTsp <- function(object, maskbuffer = 0.2, ...) {
     buf1 <- sf::st_buffer(tr, maskbuffer)
     buf2 <- sf::st_union(buf1)
     area <- sf::st_area(buf2)
-    cat("Total area (within ", maskbuffer,"km of a location) : ", area, "sq.km\n\n")
-    if (!is.null(object$geom_full$centroid)) {
+    cat("\nTotal area (within ", maskbuffer,"km of a location) : ", area, "sq.km\n")
+    convex_hull <- sf::st_area(sf::st_convex_hull(sf::st_union(tr)))
+    cat("Total area (convex hull) : ", convex_hull, "sq.km\n\n")
+    if (!is.null(object$geom_full$centroid$lat)) {
       cat("Geolocation of centroid (radians):
           latitude: ", object$geom_full$centroid$lat,
           "longitude: ", object$geom_full$centroid$long,"\n\n")
@@ -168,19 +185,22 @@ summary.CRTsp <- function(object, maskbuffer = 0.2, ...) {
       output[7, 1] <- round(object$geom_full$sd_h, digits = 1)
   }
   rownames(output)[4] <- "Locations:                                            "
-  if(identical(object$geom_full$locations,object$geom_full$records)){
+
+  if(identical(object$geom_full$locations,object$geom_full$uniquelocations)){
     output[4, 1] <- object$geom_full$locations
   } else {
-    if(!is.null(object$geom_full$records)) {
+    if(!is.null(object$geom_full$locations)) {
       rownames(output)[4] <- paste0("Not aggregated. Total records: ",
-                                    object$geom_full$records,". Unique locations:")
+                                    object$geom_full$locations,". Unique locations:")
     }
-    output[4, 1] <- object$geom_full$locations
+    if(!is.null(object$geom_full$uniquelocations))
+      output[4, 1] <- object$geom_full$uniquelocations
   }
-  if (object$geom_core$locations > 0) {
+  if (object$geom_core$locations > 0 &
+      object$geom_core$locations < object$geom_full$locations) {
     output[1, 1] <- "Full"
     output[1, 2] <- "Core"
-    output[4, 2] <- object$geom_core$locations
+    output[4, 2] <- object$geom_core$uniquelocations
     if (!is.na(object$geom_core$mean_h)) {
       clustersAvailableCore <- with(object$geom_core, floor(locations/mean_h))
       output[5, 2] <- clustersAvailableCore
@@ -190,8 +210,8 @@ summary.CRTsp <- function(object, maskbuffer = 0.2, ...) {
       output[7, 2] <- round(object$geom_core$sd_h, digits = 1)
   }
   if (!is.null(object$trial$arm) & !identical(object$trial$arm,character(0))) {
-    sd1 <- ifelse(is.null(object$geom_full$sd_distance), NA, object$geom_full$sd_distance)
-    sd2 <- ifelse(is.null(object$geom_core$sd_distance), NA, object$geom_core$sd_distance)
+    sd1 <- ifelse(is.null(object$geom_full$sigma_x), NA, object$geom_full$sigma_x)
+    sd2 <- ifelse(is.null(object$geom_core$sigma_x), NA, object$geom_core$sigma_x)
     rownames(output)[8] <- "S.D. of distance to nearest discordant location (km): "
     output[8, 1] <- ifelse(is.na(sd1), "", round(sd1, digits = 2))
     output[8, 2] <- ifelse(is.na(sd2), "", round(sd2, digits = 2))
@@ -203,6 +223,7 @@ summary.CRTsp <- function(object, maskbuffer = 0.2, ...) {
     }
   } else {
     if (is.null(object$trial$x)) {
+      rownames(output)[8] <- "    "
       rownames(output)[9] <- "No locations to randomize"
     } else {
       rownames(output)[9] <- "No randomization"
@@ -257,6 +278,8 @@ summary.CRTsp <- function(object, maskbuffer = 0.2, ...) {
       } else {
         output[3, 1] <- "No buffer"
       }
+    } else {
+      rownames(output)[3] <- " "
     }
   }
 
@@ -264,42 +287,54 @@ summary.CRTsp <- function(object, maskbuffer = 0.2, ...) {
   if (is.null(object$design$effect)) {
     rownames(output)[17] <- "No power calculations to report"
   } else {
-    rownames(output)[17] <- "\nPower calculations (ignoring spillover)\n------------------                    "
+    rownames(output)[17] <- "\nPower calculations\n------------------                    "
 
     sufficient <- ifelse(clustersAvailableFull >= object$geom_full$clustersRequired,
                          "Yes", "No")
     rownames(output)[18] <- "Design effect:                         "
     output[18, 1] <- round(object$geom_full$DE, digits = 1)
-    rownames(output)[19] <- "Nominal power (%)                      "
-    output[19, 1] <- round(object$geom_full$power * 100, digits = 1)
-    rownames(output)[20] <- paste0("Total clusters required (power of ",
+    if (object$geom_full$contaminate_pop_pr > 0) {
+      rownames(output)[19] <- paste0("Spillover affecting ",
+        round(object$geom_full$contaminate_pop_pr*100, digits = 1),
+      "% of data,\n  ", object$design$distance_distribution," model gives bias estimate:")
+      output[19, 1] <- round(object$geom_full$delta, digits = 3)
+    } else {
+      rownames(output)[19] <- "Calculations ignoring spillover"
+    }
+    rownames(output)[20] <- "Nominal power (%)                      "
+    output[20, 1] <- round(object$geom_full$power * 100, digits = 1)
+    rownames(output)[21] <- paste0("Total clusters required (power of ",
                                    object$design$desiredPower * 100, "%):")
-    output[20, 1] <- object$geom_full$clustersRequired
-    rownames(output)[21] <- "Sufficient clusters for required power?"
-    output[21, 1] <- sufficient
+    output[21, 1] <- object$geom_full$clustersRequired
+    rownames(output)[22] <- "Sufficient clusters for required power?"
+    output[22, 1] <- sufficient
 
     if (is.null(object$geom_core$power)) {
-      output <- subset(output, select = -c(2))
+      required_cols <- c(1, 3)
     } else {
+      required_cols <- c(1, 2)
       output[17, 1] <- "Full"
       output[17, 2] <- "Core"
       clustersAvailableCore <- with(object$geom_core, floor(locations/mean_h))
       sufficientCore <- ifelse(clustersAvailableCore >= object$geom_core$clustersRequired,
                                "Yes", "No")
-
       output[18, 2] <- round(object$geom_core$DE, digits = 1)
-      output[19, 2] <- round(object$geom_core$power * 100, digits = 1)
-      output[20, 2] <- object$geom_core$clustersRequired
-      output[21, 2] <- sufficientCore
+      if (object$geom_core$contaminate_pop_pr > 0) {
+        output[19, 2] <- round(object$geom_core$delta, digits = 3)
+      }
+      output[20, 2] <- round(object$geom_core$power * 100, digits = 1)
+      output[21, 2] <- object$geom_core$clustersRequired
+      output[22, 2] <- sufficientCore
     }
   }
-  standard.names <- c("x", "y", "cluster", "arm", "buffer", "nearestDiscord",
+  standard_names <- c("x", "y", "cluster", "arm", "buffer", "nearestDiscord",
                       "geom_full", "geom_core", "design")
-  rownames(output)[22] <- "\nOther variables in dataset\n--------------------------"
-  output[22, 1] <- paste(dplyr::setdiff(names(object$trial), standard.names), collapse = "  ")
-  output <- output[trimws(output[, 1]) != "", ]
+  rownames(output)[23] <- "\nOther variables in dataset\n--------------------------"
+  output[23, 1] <- paste(dplyr::setdiff(names(object$trial), standard_names), collapse = "  ")
+  required_rows <- seq(1:nrow(output))[nchar(output[, 1]) > 0 & substr(rownames(output), 1, 3) != 'row']
+  output1 <- output[required_rows, required_cols]
   # display and return table
-  utils::write.table(output, quote = FALSE, col.names = FALSE, sep = "          ")
+  utils::write.table(output1, quote = FALSE, col.names = FALSE, sep = "          ")
   options(digits = defaultdigits)
   invisible(object)
 }
