@@ -3,7 +3,7 @@
 # A separate seed should be set for each processor.
 get_test9 = function(){
   if (identical(system.file(package='INLA'), "")){
-    return(1342)
+    return(1335)
   } else {
     set.seed(1234)
     example_locations <- readdata('example_site.csv')
@@ -19,7 +19,7 @@ get_test9 = function(){
                              generateBaseline = FALSE,
                              baselineNumerator = "RDT_test_result",
                              baselineDenominator = "base_denom",
-                             ICC_inp = 0.05, theta_inp = 0.8)
+                             ICC_inp = 0.05, spillover_interval = 0.8)
     # Reading in the inla.mesh functions when run outside the check but not as part of a check
     library(Matrix)
     inla_mesh <- readdata("examplemesh100.rds")
@@ -32,5 +32,5 @@ get_test9 = function(){
   }
 }
 test_that("Analysis using INLA option gives expected DIC", {
-  expect_equal(get_test9(), 1342)
+  expect_equal(get_test9(), 1335)
 })
